@@ -5,7 +5,7 @@ use super::font_loader::EmbeddedFontAssetLoader;
 pub struct FontPlugin;
 
 impl Plugin for FontPlugin {
-    fn build(&self, app: &mut AppBuilder) {
+    fn build(&self, app: &mut App) {
         app.init_asset_loader::<EmbeddedFontAssetLoader>();
     }
 }
