@@ -8,6 +8,7 @@ use notation_model::prelude::{
 
 use crate::chord::chord_note::{ChordNoteData, ChordNoteExtra, ChordNoteValue};
 use crate::prelude::{NotationAssets, NotationSettings, NotationTheme};
+use crate::theme::theme_texts::MelodyTexts;
 
 #[derive(Clone, Debug)]
 pub struct FretFingerExtra {
@@ -160,6 +161,7 @@ impl FretFingerData {
         assets: &NotationAssets,
         theme: &NotationTheme,
         settings: &NotationSettings,
+        text_query: &Query<(&Parent, Entity), With<Text>>,
         entity: Entity,
         meta: &TabMeta,
     ) {
@@ -170,14 +172,20 @@ impl FretFingerData {
         } else {
             meta.key.transpose(Semitones(self.value.extra.capo as i8))
         };
+        for (parent, text_entity) in text_query.iter() {
+            if parent.0 == entity {
+                commands.entity(text_entity).despawn();
+            }
+        }
         if settings.show_guitar_syllable && self.value.extra.fret.is_some() {
+            let syllable = self.value.calc_syllable();
             theme.guitar.syllable_text.spawn_scaled_syllable_text(
                 commands,
                 entity,
                 assets,
                 settings,
                 &meta.scale, &key,
-                &self.value.calc_syllable(),
+                &syllable,
                 size_scale,
             )
         }
