@@ -20,6 +20,7 @@ pub struct ThemeZ {
     pub guitar_view: f32,
     pub guitar_string: f32,
     pub guitar_capo: f32,
+    pub guitar_barre: f32,
     pub tab_header: f32,
     pub rhythm_bar: f32,
     pub chord_diagram: f32,
@@ -46,6 +47,7 @@ impl Default for ThemeZ {
             guitar_view: 20.0,
             guitar_string: 23.0,
             guitar_capo: 24.0,
+            guitar_barre: 24.0,
             tab_header: 20.0,
             rhythm_bar: 22.0,
             chord_diagram: 22.0,
